..
    Copyright (C) 2024 Graz University of Technology.

    Invenio-Curations is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Authors
=======

InvenioRDM module for curation management

- Graz University of Technology
